import argparse
import sys

from postinstall import register
from postinstall import unregister_svm
from postinstall import delete_mps_records
from constants import PrecheckPlugin
from precheck.plugin_base import PluginBase

# initialize plugins for precheck
PRECHECK_PLUGINS = {p.id: p for p in PluginBase.plugins}


def main():
    parser = argparse.ArgumentParser(description='Python utilities module for Malware Prevention')
    parser.add_argument('--register-mps-feature', action="store_true", required=False,
                        help="Invoke API on NSX manager to register Malware Prevention")
    parser.add_argument('--unregister-mps-feature', action="store_true", required=False,
                            help="Invoke API on NSX manager to unregister Malware Prevention")
    parser.add_argument('--delete-kafka-offset', action="store_true", required=False,
                        help="Delete kafka offset entries in database")
    parser.add_argument('--validate-license', action="store_true", required=False,
                            help="Invoke API on NSX manager to retrieve licenses and "
                                 "validate if minimum requirements are met")
    args = parser.parse_args()

    if args.register_mps_feature:
        print("Registering Malware Prevention feature.")
        register.ui_plugin()
    elif args.unregister_mps_feature:
        print("Unregister Malware prevention feature")
        register.ui_plugin(unregister=True)
        unregister_svm.delete_service_definition()
        delete_mps_records.delete_records()
    elif args.delete_kafka_offset:
        print("Delete kafka offset")
        delete_mps_records.delete_kafka_offset()
    elif args.validate_license:
        license_plugin = PRECHECK_PLUGINS[PrecheckPlugin.LICENSE]()
        license_plugin.check()
    else:
        parser.print_help()

try:
    main()
except Exception as e:
    print(e)
    sys.exit(1)
