from constants import CheckStatus
from constants import Feature
from constants import PrecheckPlugin
from constants import Url
from constants import Licenses
from precheck.plugin_base import PluginBase
from utils import requests_wrapper


class PluginLicense(PluginBase):
    id = PrecheckPlugin.LICENSE
    name = "feature.precheck.licenseName"
    desc = "feature.precheck.licenseDesc"
    feature = Feature.MALWAREPREVENTION

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")
            # create request parameters
            print("Calling NSX manager to get license information")
            response = requests_wrapper.egress_request(
                'GET', Url.Egress.GET_LICENSE_ALL)
            #print("response received {response}".format(response=response.text))
            json_response = response.json()
            valid_license_found = False
            for license_item in json_response["results"]:
               description = license_item["description"]
               is_expired = license_item["is_expired"]
               if (description in Licenses.VALID_LICENSE_LIST):
                    valid_license_found = True
                    break
               elif (description == Licenses.NSX_EVALUATION and not is_expired):
                    valid_license_found = True
                    break

            if not valid_license_found:
                self.report_check_status(
                    CheckStatus.FAILED,
                    "feature.precheck.licenseFailReason: {valid_licenses}".format(
                        valid_licenses=Licenses.VALID_LICENSE_LIST))
            else:
                self.report_check_status(CheckStatus.SUCCESS)
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED,
                "API invocation failed: {msg}".format(msg=e))
            print(e)
            raise